==> react-native-hide-modal-0.1.0.tgz: package/README.md <==
# react-native-hide-modal

[![PRs Welcome](https://img.shields.io/badge/PRs-Welcome-brightgreen.svg)](https://github.com/heyman333/react-native-responsive-fontSize/pulls)
[![Platform](https://img.shields.io/badge/platform-react--native-lightgrey.svg)](http://facebook.github.io/react-native/)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/heyman333/react-native-responsive-fontSize/blob/master/LICENSE)

<strong>Modal component that provides the ability to hide</strong>

<hr />

## install

This library is based on the latest react-native version and uses the `react-native-community/async-storage` 
based on the react-native team's recommendation

Therefore, the following procedure is required to use this library.

1. link async-storage [Install Guide](https://github.com/react-native-community/async-storage/tree/LEGACY#getting-started)

2. npm or yarn 
    ```shell 
      npm install react-native-hide-modal --save
      #or
      yarn add react-native-hide-modal
    ```




## props

<table>
      <thead>
        <tr>
          <th></th>
          <th>type</th>
          <th>default</th>
          <th>required</th>
          <th>desc</th>
        </tr>
      </thead>
      <tbody>
        <tr>
          <th>children</th>
          <td>component</td>
          <td>undefined</td>
          <td>true</td>
          <td>Your modal view with check option</td>
        </tr>
        <tr>
          <th>id</th>
          <td>string</td>
          <td>undefined</td>
          <td>true</td>
          <td>It is used as a key value to distinguish the modal. And all key values must be unique <strong>(important)</strong></td>
        </tr>
        <tr>
          <th>modalProps</th>
          <td>object</td>
          <td>undefined</td>
          <td>false</td>
          <td>RN's modal property except for <b>visible</b>
            <br/>
            <a herf="https://facebook.github.io/react-native/docs/modal#props-1" target="_blank" >Official document</a>
          </td>
        </tr>
        <tr>
          <th>modalVisible</th>
          <td>string</td>
          <td>false</td>
          <td>true</td>
          <td>Basically, determine if modal is visible or not</td>
        </tr>
        <tr>
          <th>hideChecked</th>
          <td>boolean</td>
          <td>false</td>
          <td>true</td>
          <td>Indicates whether the user checked the checkbox.
It does not work if the prop does not pass properly.</td>
        </tr>
        <tr>
          <th>invisibleDuration</th>
          <td>number</td>
          <td>null</td>
          <td>false</td>
          <td>Assuming the data is set, decide how long to hide the modal. Modal is not visible permanently unless you pass the duration <i>(millisecond)</i></td>
        </tr>
      </tbody>
</table>

## screenshots

<div style="display: flex;">
 <img src="img/default.gif" alt="screenshot1" height="550" />
 <img src="img/withInvisibleDuration.gif" alt="screenshot1" height="550" style="margin-left: 130px;"/>
</div>

## examples
[Link](https://github.com/heyman333/react-native-hide-modal/blob/master/examples/App.js)

## author
[heyman333](https://github.com/heyman333), Frontend Developer interested in React.js & React-Native 

## loadmap
- [ ] define index.d.ts file
- [ ] make react-hide-modal(web version using React.js)
- [ ] set circle ci

==> react-native-hide-modal-0.1.1.tgz: package/README.md <==
# react-native-hide-modal

[![PRs Welcome](https://img.shields.io/badge/PRs-Welcome-brightgreen.svg)](https://github.com/heyman333/react-native-responsive-fontSize/pulls)
[![Platform](https://img.shields.io/badge/platform-react--native-lightgrey.svg)](http://facebook.github.io/react-native/)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/heyman333/react-native-responsive-fontSize/blob/master/LICENSE)

<strong>Modal component that provides the ability to hide</strong>

<hr />

## install

This library is based on the latest react-native version and uses the `react-native-community/async-storage` 
based on the react-native team's recommendation

Therefore, the following procedure is required to use this library.

1. link async-storage [Install Guide](https://github.com/react-native-community/async-storage/tree/LEGACY#getting-started)

2. npm or yarn 
    ```shell 
      npm install react-native-hide-modal --save
      #or
      yarn add react-native-hide-modal
    ```




## props

<table>
      <thead>
        <tr>
          <th></th>
          <th>type</th>
          <th>default</th>
          <th>required</th>
          <th>desc</th>
        </tr>
      </thead>
      <tbody>
        <tr>
          <th>children</th>
          <td>component</td>
          <td>undefined</td>
          <td>true</td>
          <td>Your modal view with check option</td>
        </tr>
        <tr>
          <th>id</th>
          <td>string</td>
          <td>undefined</td>
          <td>true</td>
          <td>It is used as a key value to distinguish the modal. And all key values must be unique <strong>(important)</strong></td>
        </tr>
        <tr>
          <th>modalProps</th>
          <td>object</td>
          <td>undefined</td>
          <td>false</td>
          <td>RN's modal property except for visible
            <br/>
            <a href="https://facebook.github.io/react-native/docs/modal#props-1" target="_blank">Official document</a>
          </td>
        </tr>
        <tr>
          <th>modalVisible</th>
          <td>string</td>
          <td>false</td>
          <td>true</td>
          <td>Basically, determine if modal is visible or not</td>
        </tr>
        <tr>
          <th>hideChecked</th>
          <td>boolean</td>
          <td>false</td>
          <td>true</td>
          <td>Indicates whether the user checked the checkbox.
It does not work if the prop does not pass properly.</td>
        </tr>
        <tr>
          <th>invisibleDuration</th>
          <td>number</td>
          <td>null</td>
          <td>false</td>
          <td>Assuming the data is set, decide how long to hide the modal. Modal is not visible permanently unless you pass the duration <i>(millisecond)</i></td>
        </tr>
      </tbody>
</table>

## screenshots
<img src="img/default.gif" alt="screenshot1" height="590" />
<img src="img/withInvisibleDuration.gif" alt="screenshot1" height="590"/>

## examples
[Link](https://github.com/heyman333/react-native-hide-modal/blob/master/examples/App.js)

## author
[heyman333](https://github.com/heyman333), Frontend Developer interested in React.js & React-Native 

## loadmap
- [ ] define index.d.ts file
- [ ] make react-hide-modal(web version using React.js)
- [ ] set circle ci
